This function calculates the value of f0 based on the component, where the components represent the transmission routes: Co-Primary (CP), Primary-Secondary (PS), Primary-Tertiary (PT), and Primary-Quaternary (PQ) and beyond. We split the PS, PT, PQ (and higher) routes into two parts, such that
component 1: CP route
components 2+3: PS route
components 4+5: PT route
components 2i + (2i+1): route i+1
Arguments
- x
numeric; the value at which to evaluate the function.
- mu
numeric; the mean value.
- sigma
numeric; the standard deviation.
- comp
integer; the component number. Component 1 is Co-Primary. Even components 2i are positive routes, odd components 2i+1 are negative routes (normal only).
- dist
string; assumed distribution of the serial interval; takes "normal" or "gamma"; defaults to "normal"
- wind
The window censure interval
Details
If the dist = gamma, then the mean (\(\mu\)) and standard deviation (sigma) are converted into the shape (k) and scale (theta) parameters for the gamma distribution, such that the mean (\(\mu\) ) and variance (\(\sigma^2\)) are given by: $$\mu = k \times \theta$$ $$\sigma^2 = k \times \theta^2$$.