conv_tri_dist: Convolution of the triangular distribution with the mixture component density (continuous case)
Description
We split the folded normal distribution for Primary-Secondary, Primary-Tertiary and Primary-Quaternary routes into two parts
component 1: Co-Primary route
component 2+3: Primary-Secondary route
component 4+5: Primary-Tertiary route
component 6+7: Primary-Quaternary route
Usage
conv_tri_dist(x, sigma = sd(x), r = x, mu = mean(x), route, quantity = "zero")
Value
vector of density draws for each value of x
Arguments
- x
vector of index case to case intervals
- sigma
standard deviation of density distribution
- r
description??
- mu
mean of density distribution
- route
integer; between 1 and 7 and indicates the route of transmission.
- quantity
character; "zero", "lower", "upper"
Examples
Run this codeiccs <- 1:30
conv_tri_dist(x = iccs, route = 1)
Run the code above in your browser using DataLab